.. _whatsnew:

**********
What's New
**********

These are new features and improvements of note in each release.

.. include:: whatsnew/v0.8.1.rst
.. include:: whatsnew/v0.8.0.rst
.. include:: whatsnew/v0.7.2.rst
.. include:: whatsnew/v0.7.1.rst
.. include:: whatsnew/v0.7.0.rst
.. include:: whatsnew/v0.6.3.rst
.. include:: whatsnew/v0.6.2.rst
.. include:: whatsnew/v0.6.1.rst
.. include:: whatsnew/v0.6.0.rst
.. include:: whatsnew/v0.5.2.rst
.. include:: whatsnew/v0.5.1.rst
.. include:: whatsnew/v0.5.0.rst
.. include:: whatsnew/v0.4.5.txt
.. include:: whatsnew/v0.4.4.txt
.. include:: whatsnew/v0.4.3.txt
.. include:: whatsnew/v0.4.2.txt
.. include:: whatsnew/v0.4.1.txt
.. include:: whatsnew/v0.4.0.txt
.. include:: whatsnew/v0.3.3.txt
.. include:: whatsnew/v0.3.2.txt
.. include:: whatsnew/v0.3.1.txt
.. include:: whatsnew/v0.3.0.txt
.. include:: whatsnew/v0.2.2.txt
.. include:: whatsnew/v0.2.1.txt
.. include:: whatsnew/v0.2.0.txt
.. include:: whatsnew/v0.1.0.txt
